# Utils Module
# Provides shared utilities for image I/O operations and data handling

from .image import Image
from .result import Result

__all__ = ["Image", "Result"]
